@@ -160,6 +160,21 @@ workflow_show = snapshot(
             ("parameters_order", "source"),
             ("parameters_section_style", "list"),
         ): external("hash:22929d6c2b70*.html"),
+        (
+            ("identifier", ".github/workflows/reusable-workflow.yml"),
+            ("show_signature", True),
+            ("signature_show_permissions", True),
+        ): external("hash:b6163f7b64f0*.html"),
+        (
+            ("identifier", ".github/workflows/read-write-workflow.yml"),
+            ("show_signature", True),
+            ("signature_show_permissions", True),
+        ): external("hash:9cc6f18114bf*.html"),
+        (
+            ("identifier", ".github/workflows/write-all-workflow.yml"),
+            ("show_signature", True),
+            ("signature_show_permissions", True),
+        ): external("hash:8bacb89d7527*.html"),
     }
 )
 
